==> libminc-2.4.06_1.darwin_18.x86_64.tbz2: opt/local/lib/cmake/LIBMINC/LIBMINCConfig.cmake <==
# LIBMINC CMake configuration file


get_filename_component(LIBMINC_INSTALL_PREFIX "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)
get_filename_component(LIBMINC_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH )

set(HAVE_MINC2    1)
set(HAVE_EZMINC   ON)
set(HAVE_MINC1    ON)

set(LIBMINC_NIFTI_SUPPORT )

#set(NETCDF_INCLUDE_DIR "/opt/local/include")
#set(HDF5_INCLUDE_DIR   "/opt/local/include")
#set(NIFTI_INCLUDE_DIR  "")

#set(NETCDF_LIBRARY     "/opt/local/lib/libnetcdf.dylib")
#set(HDF5_LIBRARY       "/opt/local/lib/libhdf5.dylib;/opt/local/lib/libaec/lib/libsz.dylib;/opt/local/lib/libz.dylib;/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk/usr/lib/libdl.tbd;/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk/usr/lib/libm.tbd")
#set(ZLIB_LIBRARY       "/opt/local/lib/libz.dylib")
#set(ZLIB_LIBRARIES     "/opt/local/lib/libz.dylib")
#set(NIFTI_LIBRARIES    "")

set(LIBMINC_INCLUDE_DIRS "${LIBMINC_INSTALL_PREFIX}/include") # ${LIBMINC_INSTALL_PREFIX}/include
set(LIBMINC_LIBRARY_DIRS "${LIBMINC_INSTALL_PREFIX}/lib") # ${LIBMINC_INSTALL_PREFIX}/lib
set(LIBMINC_USE_FILE     "${LIBMINC_INSTALL_PREFIX}/lib/cmake/LIBMINC/UseLIBMINC.cmake") # ${LIBMINC_INSTALL_PREFIX}/lib/UseLIBMINC.cmake

set(LIBMINC_LIBRARIES    "minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")
set(VOLUME_IO_LIBRARIES  "minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")
set(EZMINC_LIBRARIES     "minc_io;minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")

set(LIBMINC_STATIC_LIBRARIES    "")
set(VOLUME_IO_STATIC_LIBRARIES  "")

set( LIBMINC_FOUND 1 )

# VF: disable for now  
#if( NOT LIBMINC_TARGETS_IMPORTED AND NOT LIBMINC_BINARY_DIR )
#  set( LIBMINC_TARGETS_IMPORTED 1 )
#  include( "${LIBMINC_CMAKE_DIR}/LIBMINC-targets.cmake" )
#endif()

==> libminc-2.4.06_3.darwin_18.x86_64.tbz2: opt/local/lib/cmake/LIBMINC/LIBMINCConfig.cmake <==
# LIBMINC CMake configuration file


get_filename_component(LIBMINC_INSTALL_PREFIX "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)
get_filename_component(LIBMINC_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH )

set(HAVE_MINC2    1)
set(HAVE_EZMINC   ON)
set(HAVE_MINC1    ON)

set(LIBMINC_NIFTI_SUPPORT )

#set(NETCDF_INCLUDE_DIR "/opt/local/include")
#set(HDF5_INCLUDE_DIR   "/opt/local/include")
#set(NIFTI_INCLUDE_DIR  "")

#set(NETCDF_LIBRARY     "/opt/local/lib/libnetcdf.dylib")
#set(HDF5_LIBRARY       "/opt/local/lib/libhdf5.dylib;/opt/local/lib/libMacportsLegacySupport.dylib;/opt/local/lib/libaec/lib/libsz.dylib;/opt/local/lib/libz.dylib;/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk/usr/lib/libdl.tbd;/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk/usr/lib/libm.tbd")
#set(ZLIB_LIBRARY       "/opt/local/lib/libz.dylib")
#set(ZLIB_LIBRARIES     "/opt/local/lib/libz.dylib")
#set(NIFTI_LIBRARIES    "")

set(LIBMINC_INCLUDE_DIRS "${LIBMINC_INSTALL_PREFIX}/include") # ${LIBMINC_INSTALL_PREFIX}/include
set(LIBMINC_LIBRARY_DIRS "${LIBMINC_INSTALL_PREFIX}/lib") # ${LIBMINC_INSTALL_PREFIX}/lib
set(LIBMINC_USE_FILE     "${LIBMINC_INSTALL_PREFIX}/lib/cmake/LIBMINC/UseLIBMINC.cmake") # ${LIBMINC_INSTALL_PREFIX}/lib/UseLIBMINC.cmake

set(LIBMINC_LIBRARIES    "minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")
set(VOLUME_IO_LIBRARIES  "minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")
set(EZMINC_LIBRARIES     "minc_io;minc2;libm.tbd;libz.dylib;m;dl;libnetcdf.dylib")

set(LIBMINC_STATIC_LIBRARIES    "")
set(VOLUME_IO_STATIC_LIBRARIES  "")

set( LIBMINC_FOUND 1 )

# VF: disable for now  
#if( NOT LIBMINC_TARGETS_IMPORTED AND NOT LIBMINC_BINARY_DIR )
#  set( LIBMINC_TARGETS_IMPORTED 1 )
#  include( "${LIBMINC_CMAKE_DIR}/LIBMINC-targets.cmake" )
#endif()
